@@ -54,8 +54,15 @@ class _BaseBoard:
                 self.__setup(self._type,self._dev)
                 if self._dev.is_open():
                     return device
-                return None
-        return None
+                print("\033[1;33m连接失败，串口被占用\033[0m")
+                print('$#&*@{"err_code":101,"err_msg":"串口被占用","device":"mkpiano","extra":{}}@*&#$')
+            else:
+                print("\033[1;33m连接失败，未检测到串口\033[0m")
+                print('$#&*@{"err_code":101,"err_msg":"未检测到串口","device":"mkpiano","extra":{}}@*&#$')
+        else:
+            self._dev = device
+            self.__setup(self._type,self._dev)
+            return device
     
     def add_thread(self,thread):
         makeblock.add_thread(thread)
