@@ -42,7 +42,8 @@ class SerialPort():
             self._thread.daemon = True
             self._thread.start()
             mkpiano.add_port(self)
-        except Exception as e:
+        except Exception as ex:
+            print(ex)
             pass
 
     def setup(self,callback):
