@@ -19,8 +19,6 @@ class _BaseModule:
 
     def setup(self,board,idx,mode=1,period=0):
         if board._autoconnect()==False:
-            print("\033[1;33m连接失败，未检测到设备\033[0m")
-            print('$#&*@{"err_code":102,"err_msg":"未检测到设备","device":"mkpiano","extra":{}}@*&#$')
             self.quit()
         else:
             print("\033[1;32m连接成功，正在运行程序...\033[0m")
